@@ -2,7 +2,7 @@ package mRuby;
 use strict;
 use warnings;
 use 5.008008;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use XSLoader;
 
@@ -15,15 +15,21 @@ __END__
 
 =head1 NAME
 
-mRuby - A module for you
+mRuby - mruby binding for perl5.
 
 =head1 SYNOPSIS
 
-  use mRuby;
+    use mRuby;
+
+    my $mrb = mRuby::State->new();
+    my $st = $mrb->parse_string('9');
+    my $n = $mrb->generate_code($st);
+    $st->pool_close();
+    my $ret = $mrb->run($mrb->proc_new($n), undef);
 
 =head1 DESCRIPTION
 
-mRuby is
+mRuby is mruby binding for perl5.
 
 =head1 AUTHOR
 
@@ -31,6 +37,8 @@ Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>
 
 =head1 SEE ALSO
 
+L<mRuby>
+
 =head1 LICENSE
 
 Copyright (C) Tokuhiro Matsuno
